@@ -8,6 +8,7 @@
 
 #include "config.h"
 
+#include <sys/file.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <rpc/rpc.h>
@@ -52,7 +53,7 @@
 #define SIG_PF void(*)(int)
 #endif
 
-#define UNFS_NAME "UNFS3 unfsd 0.9.17 (C) 2006, Pascal Schmidt <unfs3-server@ewetel.net>\n"
+#define UNFS_NAME "UNFS3 unfsd " PACKAGE_VERSION " (C) 2006, Pascal Schmidt <unfs3-server@ewetel.net>\n"
 
 /* write verifier */
 writeverf3 wverf;
@@ -67,8 +68,10 @@ unsigned int opt_nfs_port = NFS_PORT;	/* 0 means RPC_ANYSOCK */
 unsigned int opt_mount_port = NFS_PORT;
 int opt_singleuser = FALSE;
 int opt_brute_force = FALSE;
+int opt_testconfig = FALSE;
 struct in_addr opt_bind_addr;
 int opt_readable_executables = FALSE;
+char *opt_pid_file = NULL;
 
 /* Register with portmapper? */
 int opt_portmapper = TRUE;
@@ -133,13 +136,64 @@ int get_socket_type(struct svc_req *rqstp)
     return v;
 }
 
+/*
+ * write current pid to a file
+ */
+static void create_pid_file(void)
+{
+    char buf[16];
+    int fd, res, len;
+
+    if (!opt_pid_file)
+	return;
+
+    fd = backend_open_create(opt_pid_file, O_RDWR | O_CREAT | O_TRUNC, 0644);
+    if (fd == -1) {
+	logmsg(LOG_WARNING, "failed to create pid file `%s'", opt_pid_file);
+	return;
+    }
+#if defined(LOCK_EX) && defined(LOCK_NB)
+    res = backend_flock(fd, LOCK_EX | LOCK_NB);
+    if (res == -1) {
+	logmsg(LOG_WARNING, "failed to lock pid file `%s'", opt_pid_file);
+	backend_close(fd);
+	return;
+    }
+#endif
+
+    sprintf(buf, "%i\n", backend_getpid());
+    len = strlen(buf);
+
+    res = backend_pwrite(fd, buf, len, 0);
+    backend_close(fd);
+    if (res != len) {
+	logmsg(LOG_WARNING, "failed to write pid file `%s'", opt_pid_file);
+    }
+}
+
+/*
+ * remove pid file
+ */
+static void remove_pid_file(void)
+{
+    int res;
+
+    if (!opt_pid_file)
+	return;
+
+    res = backend_remove(opt_pid_file);
+    if (res == -1 && errno != ENOENT) {
+	logmsg(LOG_WARNING, "failed to remove pid file `%s'", opt_pid_file);
+    }
+}
+
 /*
  * parse command line options
  */
 static void parse_options(int argc, char **argv)
 {
     int opt = 0;
-    char *optstring = "bcC:de:hl:m:n:prstuw";
+    char *optstring = "bcC:de:hl:m:n:prstTuwi:";
 
     while (opt != -1) {
 	opt = getopt(argc, argv, optstring);
@@ -177,6 +231,7 @@ static void parse_options(int argc, char **argv)
 		printf("\t-u          use unprivileged port for services\n");
 		printf("\t-d          do not detach from terminal\n");
 		printf("\t-e <file>   file to use instead of /etc/exports\n");
+		printf("\t-i <file>   write daemon pid to given file\n");
 #ifdef WANT_CLUSTER
 		printf("\t-c          enable cluster extensions\n");
 		printf("\t-C <path>   set path for cluster extensions\n");
@@ -192,6 +247,7 @@ static void parse_options(int argc, char **argv)
 		    ("\t-l <addr>   bind to interface with specified address\n");
 		printf
 		    ("\t-r          report unreadable executables as readable\n");
+                printf("\t-T          test exports file and exit\n");
 		exit(0);
 		break;
 	    case 'l':
@@ -235,10 +291,16 @@ static void parse_options(int argc, char **argv)
 	    case 't':
 		opt_tcponly = TRUE;
 		break;
+            case 'T':
+                opt_testconfig = TRUE;
+                break;
 	    case 'u':
 		opt_nfs_port = 0;
 		opt_mount_port = 0;
 		break;
+	    case 'i':
+		opt_pid_file = optarg;
+		break;
 	    case '?':
 		exit(1);
 		break;
@@ -288,6 +350,7 @@ void daemon_exit(int error)
     if (opt_detach)
 	closelog();
 
+    remove_pid_file();
     backend_shutdown();
 
     exit(1);
@@ -795,6 +858,17 @@ int main(int argc, char **argv)
 	daemon_exit(0);
     }
 
+    /* config test mode */
+    if (opt_testconfig) {
+        res = exports_parse();
+        if (res) {
+          exit(0);
+        } else {
+          fprintf(stderr, "Parse error in `%s'\n", opt_exports);
+          exit(1);
+        }
+    }
+
     if (opt_detach) {
 	/* prepare syslog access */
 	openlog("unfsd", LOG_CONS | LOG_PID, LOG_DAEMON);
@@ -863,6 +937,9 @@ int main(int argc, char **argv)
 	/* no umask to not screw up create modes */
 	umask(0);
 
+	/* create pid file if wanted */
+	create_pid_file();
+
 	/* initialize internal stuff */
 	fh_cache_init();
 	fd_cache_init();
