@@ -7,6 +7,8 @@
 #ifndef UNFS3_DAEMON_H
 #define UNFS3_DAEMON_H
 
+#include "nfs.h"
+
 /* exit status for internal errors */
 #define CRISIS	99
 
@@ -25,17 +27,19 @@ void logmsg(int, const char *, ...);
 /* remote address */
 struct in_addr get_remote(struct svc_req *);
 short get_port(struct svc_req *);
+int get_socket_type(struct svc_req *rqstp);
 
 /* write verifier */
 extern writeverf3 wverf;
+void regenerate_write_verifier(void);
 
 /* options */
-extern int	opt_expire_writers;
 extern int	opt_detach;
 extern char	*opt_exports;
 extern int	opt_cluster;
 extern char	*opt_cluster_path;
 extern int	opt_singleuser;
 extern int	opt_brute_force;
+extern int	opt_readable_executables;
 
 #endif
